| Title: | A Posteriori Probs of Suits Breaking Evenly Across Four Hands |
|---|---|
| Description: | We quantitatively evaluated the assertion that says if one suit is found to be evenly distributed among the 4 players, the rest of the suits are more likely to be evenly distributed. Our mathematical analyses show that, if one suit is found to be evenly distributed, then a second suit has a slightly elevated probability (ranging between 10% to 15%) of being evenly distributed. If two suits are found to be evenly distributed, then a third suit has a substantially elevated probability (ranging between 30% to 50%) of being evenly distributed.This package refers to methods and authentic data from Ely Culbertson <https://www.bridgebum.com/law_of_symmetry.php>, Gregory Stoll <https://gregstoll.com/~gregstoll/bridge/math.html>, and details of performing the probability calculations from Jeremy L. Martin <https://jlmartin.ku.edu/~jlmartin/bridge/basics.pdf>, Emile Borel and Andre Cheron (1954) "The Mathematical Theory of Bridge",Antonio Vivaldi and Gianni Barracho (2001, ISBN:0 7134 8663 5) "Probabilities and Alternatives in Bridge", Ken Monzingo (2005) "Hand and Suit Patterns" <http://web2.acbl.org/documentlibrary/teachers/celebritylessons/handpatternsrevised.pdf>Ken Monzingo (2005) "Hand and Suit Patterns" <http://web2.acbl.org/documentlibrary/teachers/celebritylessons/handpatternsrevised.pdf>. |
| Authors: | Barry Zeeberg [aut, cre] |
| Maintainer: | Barry Zeeberg <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-05-14 05:19:10 UTC |
| Source: | https://github.com/cran/evenBreak |
organizes invoking evenBreakDriver() for 4 deck sizes, and presenting the results in a table
and in a graph scatter plot of 2 sets of distribution probabilities
compareProbs(verbose)compareProbs(verbose)
verbose |
Boolean if TRUE print output data |
returns no value, but has side effects of printing a table and a graph
of the probability of a given distribution of a single suit across 4 hands,
conditioned on the number of suits that are known to be evenly distributed.
Barry Zeeberg
compareProbs()compareProbs()
compute the probability of a given distribution of a single suit across 4 hands
evenBreak(D4,n1,n2,n3,PERM)evenBreak(D4,n1,n2,n3,PERM)
D4 |
one quarter of the size of the deck, normally = 13 |
n1 |
the number of cards in the suit in the hands of player 1 |
n2 |
the number of cards in the suit in the hands of player 2 |
n3 |
the number of cards in the suit in the hands of player 3 |
PERM |
the number of permutations |
returns the probability of a given distribution of a single suit across 4 hands
Barry Zeeberg
n1<-3 n2<-3 n3<-3 n4<-13-(n1+n2+n3) PERM<-length(unique(combinat::permn(c(n1,n2,n3,n4)))) PERM evenBreak(13,n1,n2,n3,1)*length(unique(combinat::permn(c(n1,n2,n3,n4))))n1<-3 n2<-3 n3<-3 n4<-13-(n1+n2+n3) PERM<-length(unique(combinat::permn(c(n1,n2,n3,n4)))) PERM evenBreak(13,n1,n2,n3,1)*length(unique(combinat::permn(c(n1,n2,n3,n4))))
loop through all possible distributions of a single suit across 4 hands
evenBreakDriver(D4)evenBreakDriver(D4)
D4 |
one quarter of the size of the deck, normally = 13 |
returns a table of the probability of a given distribution of a single suit across 4 hands,
conditioned on the number of suits that are known to be evenly distributed.
Barry Zeeberg
evenBreakDriver(13)evenBreakDriver(13)